var group__spa__support =
[
    [ "spa_cpu", "structspa__cpu.html", [
      [ "iface", "structspa__cpu.html#a4822c09d9eb0c57ca8d7b6e8ed4bfcda", null ]
    ] ],
    [ "spa_cpu_methods", "structspa__cpu__methods.html", [
      [ "force_flags", "structspa__cpu__methods.html#a52a1db59dcb261cd6348733232932a66", null ],
      [ "get_count", "structspa__cpu__methods.html#a700fe283edbd95218d18e6c5cac7f327", null ],
      [ "get_flags", "structspa__cpu__methods.html#a705910a6b831fd551b298ad64182598f", null ],
      [ "get_max_align", "structspa__cpu__methods.html#a269e1e0cff0d3674d92b9d4935089aa8", null ],
      [ "get_vm_type", "structspa__cpu__methods.html#acd636f83ca2db246adfc92fc7d669204", null ],
      [ "version", "structspa__cpu__methods.html#afc8c065c16934356a464235e38aae666", null ]
    ] ],
    [ "spa_dbus", "structspa__dbus.html", [
      [ "iface", "structspa__dbus.html#a240c318013b1a4441195fa94f213b65b", null ]
    ] ],
    [ "spa_dbus_connection_events", "structspa__dbus__connection__events.html", [
      [ "destroy", "structspa__dbus__connection__events.html#a1e35b4f490157dd9c4194b4a03490fc6", null ],
      [ "disconnected", "structspa__dbus__connection__events.html#a481b39049a46ec7d8519c8d2c9318968", null ],
      [ "version", "structspa__dbus__connection__events.html#a2ae8b95b36226127853160f1779260e0", null ]
    ] ],
    [ "spa_dbus_connection", "structspa__dbus__connection.html", [
      [ "add_listener", "structspa__dbus__connection.html#a2e21fc21219047d9bdc8e1994a23acea", null ],
      [ "destroy", "structspa__dbus__connection.html#a1b0a0400c311d50b764f100b4b50bf8f", null ],
      [ "get", "structspa__dbus__connection.html#a684f175f4839121d8c976c50ca273303", null ],
      [ "version", "structspa__dbus__connection.html#a8b89c910cd288a5e1d2af8216568a3a6", null ]
    ] ],
    [ "spa_dbus_methods", "structspa__dbus__methods.html", [
      [ "get_connection", "structspa__dbus__methods.html#a1e518bcb13046ec6b46a927024b6cc28", null ],
      [ "version", "structspa__dbus__methods.html#a6e090fa6083fa425460f631ea48c3434", null ]
    ] ],
    [ "spa_i18n", "structspa__i18n.html", [
      [ "iface", "structspa__i18n.html#a4ca10c865fe33ffff4fd9abb9265c0f8", null ]
    ] ],
    [ "spa_i18n_methods", "structspa__i18n__methods.html", [
      [ "ntext", "structspa__i18n__methods.html#a884391486c3277069fb8ee2f9d754234", null ],
      [ "text", "structspa__i18n__methods.html#a7ceb5c3a7165fbfb3ee340574881d675", null ],
      [ "version", "structspa__i18n__methods.html#a3aa971d572e886ab027a897a288f767b", null ]
    ] ],
    [ "spa_loop", "structspa__loop.html", [
      [ "iface", "structspa__loop.html#a6cd472082b361bc90f66c41b0dccea96", null ]
    ] ],
    [ "spa_loop_control", "structspa__loop__control.html", [
      [ "iface", "structspa__loop__control.html#a392f811fbacb15de863fc0265031050f", null ]
    ] ],
    [ "spa_loop_utils", "structspa__loop__utils.html", [
      [ "iface", "structspa__loop__utils.html#afd3c579e127e4a5d22c1d407e01b2803", null ]
    ] ],
    [ "spa_source", "structspa__source.html", [
      [ "data", "structspa__source.html#a71de19fa483b3cff326286337642c4f7", null ],
      [ "fd", "structspa__source.html#ae6a0bb20a4c3b21ae6e622c1685711a8", null ],
      [ "func", "structspa__source.html#add060762781a845877ffe088e4bb2a8d", null ],
      [ "loop", "structspa__source.html#afa3497b4d040a33cacc301d261786306", null ],
      [ "mask", "structspa__source.html#ad43d6b5fd83f3e86be4f6103009370cd", null ],
      [ "rmask", "structspa__source.html#a3b403afec9c365892ab175f5613a9eff", null ]
    ] ],
    [ "spa_loop_methods", "structspa__loop__methods.html", [
      [ "add_source", "structspa__loop__methods.html#a3cc011aae850f2eda426b98655c4a43c", null ],
      [ "invoke", "structspa__loop__methods.html#a7852de4b031351b586ed1f5375fdc863", null ],
      [ "remove_source", "structspa__loop__methods.html#a72835084d3a698702f9c875ae5aada7a", null ],
      [ "update_source", "structspa__loop__methods.html#aa1c58c24c44c6161f7c5d81910cc5acc", null ],
      [ "version", "structspa__loop__methods.html#ae7dc5184539a2425309dee69d2867dcf", null ]
    ] ],
    [ "spa_loop_control_hooks", "structspa__loop__control__hooks.html", [
      [ "after", "structspa__loop__control__hooks.html#a94545cf994d47a1acc84437e5c357141", null ],
      [ "before", "structspa__loop__control__hooks.html#a129526ea88e29db103f01666a32c2d20", null ],
      [ "version", "structspa__loop__control__hooks.html#a1d60078aab0c143a082ab30e91151dd2", null ]
    ] ],
    [ "spa_loop_control_methods", "structspa__loop__control__methods.html", [
      [ "add_hook", "structspa__loop__control__methods.html#a4af155a89512ec591bac117a3907e8c4", null ],
      [ "enter", "structspa__loop__control__methods.html#a4a64700ab318b03abb1a5ec5a5309f8a", null ],
      [ "get_fd", "structspa__loop__control__methods.html#a2673d98892466d81baea852c94c91a39", null ],
      [ "iterate", "structspa__loop__control__methods.html#a2d30cbd197ae33a77b5ccce2216ca61a", null ],
      [ "leave", "structspa__loop__control__methods.html#a84177384a1a726c4b35a3e1d9bc8f30f", null ],
      [ "version", "structspa__loop__control__methods.html#aa66e2f92b352ef1ae10b591f11086340", null ]
    ] ],
    [ "spa_loop_utils_methods", "structspa__loop__utils__methods.html", [
      [ "add_event", "structspa__loop__utils__methods.html#aea2ab7bb653eef26373295fafbe048fc", null ],
      [ "add_idle", "structspa__loop__utils__methods.html#a79ae6123ff0f20029d4e722053b49a11", null ],
      [ "add_io", "structspa__loop__utils__methods.html#adc8b3b97121c94a824307117dad02989", null ],
      [ "add_signal", "structspa__loop__utils__methods.html#af9604ab5944fce7539516ff227ddc2f9", null ],
      [ "add_timer", "structspa__loop__utils__methods.html#ab24aa861875574691b833aaaf356a2ad", null ],
      [ "destroy_source", "structspa__loop__utils__methods.html#acb650a30486b87fcab5859afd000d913", null ],
      [ "enable_idle", "structspa__loop__utils__methods.html#a4466703d3ee6e18abc89bafea2b0c0ed", null ],
      [ "signal_event", "structspa__loop__utils__methods.html#aa30b5933fcadb8606772d95471ec7a05", null ],
      [ "update_io", "structspa__loop__utils__methods.html#a166d2e9aab23ce96b9d7795c3466fc6b", null ],
      [ "update_timer", "structspa__loop__utils__methods.html#abc9a0d7bb777e2c892343b1ca5a6d37d", null ],
      [ "version", "structspa__loop__utils__methods.html#aefb69d2a6ad30b352b4414401a55f3e7", null ]
    ] ],
    [ "spa_plugin_loader", "structspa__plugin__loader.html", [
      [ "iface", "structspa__plugin__loader.html#a17501870cdaf04804cde83d541a31a61", null ]
    ] ],
    [ "spa_plugin_loader_methods", "structspa__plugin__loader__methods.html", [
      [ "load", "structspa__plugin__loader__methods.html#ac03d77f832ee680b4a1b68acdbcc05d4", null ],
      [ "unload", "structspa__plugin__loader__methods.html#aa91d4ff3f01f2d7c38a066b3d8bc98ca", null ],
      [ "version", "structspa__plugin__loader__methods.html#ae2de2d15c28cf425552bb3aa6ca0bad4", null ]
    ] ],
    [ "spa_system", "structspa__system.html", [
      [ "iface", "structspa__system.html#a87fdaae85b7f2321bd10b05a3c9f9b54", null ]
    ] ],
    [ "spa_poll_event", "structspa__poll__event.html", [
      [ "data", "structspa__poll__event.html#aeed4677e8ecbdfdbe4bad5735e24e570", null ],
      [ "events", "structspa__poll__event.html#a9d6d7a42bd3180152807aacb02ddbebe", null ]
    ] ],
    [ "spa_system_methods", "structspa__system__methods.html", [
      [ "clock_getres", "structspa__system__methods.html#a74ee473681fb6c5c83693d2be53f18db", null ],
      [ "clock_gettime", "structspa__system__methods.html#a97bdbd157cd2ff98a0ab09b85522960c", null ],
      [ "close", "structspa__system__methods.html#a81c5752082d2ee1f392fe3ae914d7f37", null ],
      [ "eventfd_create", "structspa__system__methods.html#a4cb1d67e7262f881d36b5c8a25f4d485", null ],
      [ "eventfd_read", "structspa__system__methods.html#a1b6a6ff161066b222f7d1746400c7127", null ],
      [ "eventfd_write", "structspa__system__methods.html#a4a677665cdba24ec2faf6f471a919fa6", null ],
      [ "ioctl", "structspa__system__methods.html#aea9a9e0adc213e0090a50e3b4883db77", null ],
      [ "pollfd_add", "structspa__system__methods.html#aae7a5c2f44c9015e351032066498d247", null ],
      [ "pollfd_create", "structspa__system__methods.html#a9288a8dd07cf29166a03829e07eb1718", null ],
      [ "pollfd_del", "structspa__system__methods.html#a13bacd57bc170f5a2342ca95de203ee2", null ],
      [ "pollfd_mod", "structspa__system__methods.html#adfaee480ca6869161824c85928c0e3d0", null ],
      [ "pollfd_wait", "structspa__system__methods.html#a407f3e0b8a2fa54b40710d965ed83afc", null ],
      [ "read", "structspa__system__methods.html#a4cd27e2c3a8daa1705da0028af779060", null ],
      [ "signalfd_create", "structspa__system__methods.html#abea413fdeedbae46e481fb1c698b81b8", null ],
      [ "signalfd_read", "structspa__system__methods.html#a29ed9ebd20b72273a3a6c0a6a6c5a3f1", null ],
      [ "timerfd_create", "structspa__system__methods.html#a448396798797647ebbf458fca65ef189", null ],
      [ "timerfd_gettime", "structspa__system__methods.html#abd9d8195afc746c4ef19428491fe00fa", null ],
      [ "timerfd_read", "structspa__system__methods.html#a7a30db95034f05fd2c8c41e78342d500", null ],
      [ "timerfd_settime", "structspa__system__methods.html#ada4083f64959db28b4a03f4032ee87e9", null ],
      [ "version", "structspa__system__methods.html#a56a305f758899158e90920cf28fd41e4", null ],
      [ "write", "structspa__system__methods.html#a9905a87c5474f3a7a6b547999bc7cc7c", null ]
    ] ],
    [ "spa_thread_utils", "structspa__thread__utils.html", [
      [ "iface", "structspa__thread__utils.html#add4d911915f7c8e76b9c646389facf70", null ]
    ] ],
    [ "spa_thread_utils_methods", "structspa__thread__utils__methods.html", [
      [ "acquire_rt", "structspa__thread__utils__methods.html#a6423900a0115ed260e5d4b15f24285f5", null ],
      [ "create", "structspa__thread__utils__methods.html#a22e5fb8af7bfdb9fe503f2562f5ed122", null ],
      [ "drop_rt", "structspa__thread__utils__methods.html#a67cf4dee89855ce72ad3c48184e1ca01", null ],
      [ "get_rt_range", "structspa__thread__utils__methods.html#a93b7072cec0d4898712b33c7a6808767", null ],
      [ "join", "structspa__thread__utils__methods.html#a32030849999e51af737dad5d2761c927", null ],
      [ "version", "structspa__thread__utils__methods.html#a68878e9b02ee15f3590d4c871a97d74a", null ]
    ] ],
    [ "SPA_CPU_FLAG_3DNOW", "group__spa__support.html#ga0a3dd46825368afac7ab58798bc02337", null ],
    [ "SPA_CPU_FLAG_3DNOWEXT", "group__spa__support.html#ga863ee498bc3630a98ee12fe569a9dc30", null ],
    [ "SPA_CPU_FLAG_AESNI", "group__spa__support.html#ga0bfa4a83c590f7bccf5aed851a40ecd6", null ],
    [ "SPA_CPU_FLAG_ALTIVEC", "group__spa__support.html#gae10fa710c9aa3527eaf37d8a3bfd72d2", null ],
    [ "SPA_CPU_FLAG_ARMV5TE", "group__spa__support.html#gac0071a662de46285708b0c8c32e4be2e", null ],
    [ "SPA_CPU_FLAG_ARMV6", "group__spa__support.html#gad24522ec05d1ded3a3d9b2a3274b0030", null ],
    [ "SPA_CPU_FLAG_ARMV6T2", "group__spa__support.html#ga94394c9aeeccf55a71dc8b786e674f40", null ],
    [ "SPA_CPU_FLAG_ARMV8", "group__spa__support.html#gaa96fa19763cd1ed32cb5cf4dba70ad31", null ],
    [ "SPA_CPU_FLAG_AVX", "group__spa__support.html#ga7d984f94a08720c709e38dc2b7f6055e", null ],
    [ "SPA_CPU_FLAG_AVX2", "group__spa__support.html#ga1b21dcf36d20e66874a49fc474db934b", null ],
    [ "SPA_CPU_FLAG_AVX512", "group__spa__support.html#ga417908a823f8fc14cce2fa5ffc68aeb7", null ],
    [ "SPA_CPU_FLAG_BMI1", "group__spa__support.html#ga9f6412675e3d21a115ea214c1f720c01", null ],
    [ "SPA_CPU_FLAG_BMI2", "group__spa__support.html#gaa6d2558bc9c0504d658b87a9c333df33", null ],
    [ "SPA_CPU_FLAG_CMOV", "group__spa__support.html#ga8e4904a089d0f96603ef7a7fb87c378f", null ],
    [ "SPA_CPU_FLAG_FMA3", "group__spa__support.html#gaa79cbeabcefc6e5e4de4dced2461bafc", null ],
    [ "SPA_CPU_FLAG_FMA4", "group__spa__support.html#ga2ab905acd508088285b27b0f4008675f", null ],
    [ "SPA_CPU_FLAG_MMX", "group__spa__support.html#ga7bf75d9047afb1801c025297f63b09cf", null ],
    [ "SPA_CPU_FLAG_MMXEXT", "group__spa__support.html#gab0e2f34eb8b3aa5f1eb74be67decae9a", null ],
    [ "SPA_CPU_FLAG_NEON", "group__spa__support.html#ga550bc6f4afa17782e88306c89cd39663", null ],
    [ "SPA_CPU_FLAG_POWER8", "group__spa__support.html#ga0059ea6fe5c017eaa03cea53573f452d", null ],
    [ "SPA_CPU_FLAG_SLOW_UNALIGNED", "group__spa__support.html#ga34938fa446a7f4078cb7da6877e855de", null ],
    [ "SPA_CPU_FLAG_SSE", "group__spa__support.html#ga43c86c77745486a5e63c4ac15f75875f", null ],
    [ "SPA_CPU_FLAG_SSE2", "group__spa__support.html#ga678997ea44550f4906f12306e8f43d76", null ],
    [ "SPA_CPU_FLAG_SSE3", "group__spa__support.html#ga7e84bb3a2f11a5a357ed8f79677234a8", null ],
    [ "SPA_CPU_FLAG_SSE41", "group__spa__support.html#gac3575bc4548e5cb7c87a9e59dce85e91", null ],
    [ "SPA_CPU_FLAG_SSE42", "group__spa__support.html#ga4ae17a1d44999ba40d7006f4b78d7787", null ],
    [ "SPA_CPU_FLAG_SSSE3", "group__spa__support.html#gad4c6b81675ec1a16c23239041970f099", null ],
    [ "SPA_CPU_FLAG_VFP", "group__spa__support.html#ga858649645d60b353cf86ddb6ee41a445", null ],
    [ "SPA_CPU_FLAG_VFPV3", "group__spa__support.html#ga30c00d8e491f8de5e86b164007ded00d", null ],
    [ "SPA_CPU_FLAG_VSX", "group__spa__support.html#gadbf1c05dc94b098500b335c980a20f73", null ],
    [ "SPA_CPU_FLAG_XOP", "group__spa__support.html#gade1463bb6f0e53ab480be27ac0b4383c", null ],
    [ "SPA_CPU_FORCE_AUTODETECT", "group__spa__support.html#ga8a8442eb592a7cb99c969edd45b55b01", null ],
    [ "spa_cpu_force_flags", "group__spa__support.html#gafd7cd22cbf0138875264c22ea79eef16", null ],
    [ "spa_cpu_get_count", "group__spa__support.html#ga51581ba204d019c69f5028919f32be27", null ],
    [ "spa_cpu_get_flags", "group__spa__support.html#gaf0b85f94092b16c66534cd3206c30870", null ],
    [ "spa_cpu_get_max_align", "group__spa__support.html#ga34a7cfa724239e524fdccf570249abf3", null ],
    [ "spa_cpu_get_vm_type", "group__spa__support.html#ga2e55408a3889771331a2e6ca1922f3da", null ],
    [ "spa_cpu_method", "group__spa__support.html#gacd9379b41a5fc4ca989f106515ab72e4", null ],
    [ "SPA_CPU_VM_ACRN", "group__spa__support.html#gaefc0478de60eb509f0c7b571d1a58622", null ],
    [ "SPA_CPU_VM_BHYVE", "group__spa__support.html#gaabed68d3b3d4db276c57891df69fbc93", null ],
    [ "SPA_CPU_VM_BOCHS", "group__spa__support.html#gac8a0291e09ea6fdcd49b2a8c3988b223", null ],
    [ "SPA_CPU_VM_KVM", "group__spa__support.html#ga898241b82efab179bd63ebea6c6e7d32", null ],
    [ "SPA_CPU_VM_MICROSOFT", "group__spa__support.html#ga7c2b2d8ee4d701b82ee6adce511f82af", null ],
    [ "SPA_CPU_VM_NONE", "group__spa__support.html#gae496a2c1b18ae116ae1c2a7b7f0e66c3", null ],
    [ "SPA_CPU_VM_ORACLE", "group__spa__support.html#ga55a34f563b11a4022002c6bc810b02bc", null ],
    [ "SPA_CPU_VM_OTHER", "group__spa__support.html#ga02fa9e6a49d1459b0a660354bc81192c", null ],
    [ "SPA_CPU_VM_PARALLELS", "group__spa__support.html#ga295af1b2fdce5f527f64dc89fd13273c", null ],
    [ "SPA_CPU_VM_POWERVM", "group__spa__support.html#ga01f23ad8364f5036eeaea855d845cc44", null ],
    [ "SPA_CPU_VM_QEMU", "group__spa__support.html#gaeaa02c7399c9c2e26501e6e220dd9910", null ],
    [ "SPA_CPU_VM_QNX", "group__spa__support.html#ga36f54e2aac3837cb3631db07cbfde3e2", null ],
    [ "SPA_CPU_VM_UML", "group__spa__support.html#gabb4142740151dfe408cb49f344da06de", null ],
    [ "SPA_CPU_VM_VMWARE", "group__spa__support.html#ga546bf71226a1fc712613f98e0009e30b", null ],
    [ "SPA_CPU_VM_XEN", "group__spa__support.html#ga83e02f29ac1083c20ddabfa5c4825386", null ],
    [ "SPA_CPU_VM_ZVM", "group__spa__support.html#gaab2a78075bf054d09f7e950150278b8b", null ],
    [ "spa_dbus_connection_add_listener", "group__spa__support.html#gaf6c34bfb6ec8349a21c8fcc589c1a6fd", null ],
    [ "spa_dbus_connection_call", "group__spa__support.html#gad2eab612eb7381bc0829bf6857b276c0", null ],
    [ "spa_dbus_connection_call_vp", "group__spa__support.html#ga38d6b3e2b9367e194e5ed4a7adbe9471", null ],
    [ "spa_dbus_connection_destroy", "group__spa__support.html#gade98eead8beb2e3e85a92eebbdaae88a", null ],
    [ "SPA_DBUS_CONNECTION_EVENT_DESTROY", "group__spa__support.html#gae64bf9807f6afbbf8e5cefce37bddd9f", null ],
    [ "SPA_DBUS_CONNECTION_EVENT_DISCONNECTED", "group__spa__support.html#gaed122ed9b453bf144717949594e6a86d", null ],
    [ "SPA_DBUS_CONNECTION_EVENT_NUM", "group__spa__support.html#gaa1bb9052d868e1185afd82668582d740", null ],
    [ "spa_dbus_connection_get", "group__spa__support.html#gab00a9b74a78715ccbcefc61d07967d59", null ],
    [ "SPA_FD_CLOEXEC", "group__spa__support.html#ga733abb5592ec21f4b66a6223255cdcbb", null ],
    [ "SPA_FD_EVENT_SEMAPHORE", "group__spa__support.html#ga52bdd44fa6a91d7072ac43c994adc7be", null ],
    [ "SPA_FD_NONBLOCK", "group__spa__support.html#ga540f4b955fcdc5533291fea09de02348", null ],
    [ "SPA_FD_TIMER_ABSTIME", "group__spa__support.html#gaea351cfc19dfe7def75926678ef7a61c", null ],
    [ "SPA_FD_TIMER_CANCEL_ON_SET", "group__spa__support.html#ga0dd7ca3def67660ca1aa93c87f5d88a5", null ],
    [ "SPA_IO_ERR", "group__spa__support.html#gad5262f91a3325573bc0cc0755bb00973", null ],
    [ "SPA_IO_HUP", "group__spa__support.html#gac69d59b92488f09f5facd97c39ef73a2", null ],
    [ "SPA_IO_IN", "group__spa__support.html#ga615390b2601f4551064d7bc5fec36737", null ],
    [ "SPA_IO_OUT", "group__spa__support.html#gae7496c8f3c9e1adf18c6fa58df0fd464", null ],
    [ "SPA_KEY_CPU_FORCE", "group__spa__support.html#gabed152078bde7fcafccb72345c40d71c", null ],
    [ "SPA_KEY_CPU_VM_TYPE", "group__spa__support.html#ga8fb893812b3fb95768f2c85419463530", null ],
    [ "spa_loop_add_source", "group__spa__support.html#ga99e724c104e06300d59b4648daff894c", null ],
    [ "spa_loop_control_add_hook", "group__spa__support.html#gaffe08d7788d04fa44c44fda7ab3649bb", null ],
    [ "spa_loop_control_enter", "group__spa__support.html#ga32dfd8283bd79d057fefb94a7e1f653c", null ],
    [ "spa_loop_control_get_fd", "group__spa__support.html#gab1b169d1e380c8af23a07c8b149139df", null ],
    [ "spa_loop_control_hook_after", "group__spa__support.html#ga9dd9301212e42d0920e8817a2de0bbc5", null ],
    [ "spa_loop_control_hook_before", "group__spa__support.html#ga11a4d14721eeda99243ae1b90b8e3bc3", null ],
    [ "spa_loop_control_iterate", "group__spa__support.html#ga3bae0b32100f5752b3372a505c8e04f6", null ],
    [ "spa_loop_control_leave", "group__spa__support.html#ga3ab19534c467fdf6055e1db9a2144e9b", null ],
    [ "spa_loop_control_method_r", "group__spa__support.html#ga4b23dfd9d8eadc0364b62ff9bdc25e82", null ],
    [ "spa_loop_control_method_v", "group__spa__support.html#ga0f531ff1357bf1f6ad225faa1f99b265", null ],
    [ "spa_loop_invoke", "group__spa__support.html#ga48cccc69f8673b5c379d2c3cd942caf4", null ],
    [ "spa_loop_method", "group__spa__support.html#ga966277f41bb16e8f06fa0f81a41bdb49", null ],
    [ "spa_loop_remove_source", "group__spa__support.html#ga6ce7a8e15eac63682e937bb05ff58859", null ],
    [ "spa_loop_update_source", "group__spa__support.html#ga8916c3ddccbeb9675ea37c545cb2cc2d", null ],
    [ "spa_loop_utils_add_event", "group__spa__support.html#gaf67b95b170f125ee503fec3640b727ca", null ],
    [ "spa_loop_utils_add_idle", "group__spa__support.html#gae8f06c860d57f4acd23159cc7799cbd5", null ],
    [ "spa_loop_utils_add_io", "group__spa__support.html#gaf18adfccc510004e0438614046e58013", null ],
    [ "spa_loop_utils_add_signal", "group__spa__support.html#gae18de1c27e64c87d1babd2e1ce384d11", null ],
    [ "spa_loop_utils_add_timer", "group__spa__support.html#ga7011bd80bca03b69aabd7a0e248c8454", null ],
    [ "spa_loop_utils_destroy_source", "group__spa__support.html#gad316355ee8463e9c6bf0f515801b1a91", null ],
    [ "spa_loop_utils_enable_idle", "group__spa__support.html#ga221f3cb24793f6525ba85d40e1829fe5", null ],
    [ "spa_loop_utils_method_r", "group__spa__support.html#gad5742d5525667f7c2287e73ec46df0e1", null ],
    [ "spa_loop_utils_method_s", "group__spa__support.html#gaa35e9bef06156668e402d9b15afa7fa5", null ],
    [ "spa_loop_utils_method_v", "group__spa__support.html#ga48a9f2265639949de21d784ca415ecc7", null ],
    [ "spa_loop_utils_signal_event", "group__spa__support.html#ga7ee15f09051cf99399fc9022a2d69ff8", null ],
    [ "spa_loop_utils_update_io", "group__spa__support.html#ga99ddf176c94a66d79f30e9e4387d12e4", null ],
    [ "spa_loop_utils_update_timer", "group__spa__support.html#ga3192e99cc1772361096a4c5d3f0fd6da", null ],
    [ "spa_system_clock_getres", "group__spa__support.html#gaed2ee0d164d71468cbebc3d3d1644abd", null ],
    [ "spa_system_clock_gettime", "group__spa__support.html#ga470bdc9dd5ec71d7f79bc893147420d0", null ],
    [ "spa_system_close", "group__spa__support.html#ga9a0a93bd110deace66ec7928965033ed", null ],
    [ "spa_system_eventfd_create", "group__spa__support.html#ga60a3b96114f829310a91613a9a84e7f5", null ],
    [ "spa_system_eventfd_read", "group__spa__support.html#ga8b0056bb9e3db8e8527bf8a83de48960", null ],
    [ "spa_system_eventfd_write", "group__spa__support.html#gafc0c4bc774b7d7f571cfc311223cd01c", null ],
    [ "spa_system_ioctl", "group__spa__support.html#gaab4122dc40f03111652545e70ee32b7c", null ],
    [ "spa_system_method_r", "group__spa__support.html#ga2e31883f569e32ad6dfcb52702d83014", null ],
    [ "spa_system_pollfd_add", "group__spa__support.html#ga2dcb97fa874ae364a19ce37d7f7ed90f", null ],
    [ "spa_system_pollfd_create", "group__spa__support.html#gacfaeac3c65fa09b4974a79735520157f", null ],
    [ "spa_system_pollfd_del", "group__spa__support.html#ga4afa9431eb60e1611908f1b984d17a22", null ],
    [ "spa_system_pollfd_mod", "group__spa__support.html#ga97e43c1810461311771e0eb3d34cbce5", null ],
    [ "spa_system_pollfd_wait", "group__spa__support.html#gaed5715eaa56338c8d14d4f43e9880782", null ],
    [ "spa_system_read", "group__spa__support.html#gaf4ac27f90f1eee63c0b3f10e7b97999a", null ],
    [ "spa_system_signalfd_create", "group__spa__support.html#gac38f48e8f24186c07905b7905e921359", null ],
    [ "spa_system_signalfd_read", "group__spa__support.html#ga1604e4f8d230b960c7bc30718297e86e", null ],
    [ "spa_system_timerfd_create", "group__spa__support.html#gaff95a55ae068dc73d2434f5bf40bdb9a", null ],
    [ "spa_system_timerfd_gettime", "group__spa__support.html#gacf1a36b269e5c44bd0a44116fc1dff52", null ],
    [ "spa_system_timerfd_read", "group__spa__support.html#ga282e1c96dc3c64fe48b01b93257191a3", null ],
    [ "spa_system_timerfd_settime", "group__spa__support.html#ga971e2cf2384a6e07a3d0ed6bc8ed776d", null ],
    [ "spa_system_write", "group__spa__support.html#gae3bdff54f3f6b5970f995d7dd1e0397a", null ],
    [ "SPA_TYPE_INFO_Thread", "group__spa__support.html#ga36d6661f31950920b85cd0c48fc68a33", null ],
    [ "SPA_TYPE_INTERFACE_CPU", "group__spa__support.html#gaa186cfc60f43633587d086ba0f85941e", null ],
    [ "SPA_TYPE_INTERFACE_DataLoop", "group__spa__support.html#ga5be1a481702843ffab8cfe42d3b6cfe1", null ],
    [ "SPA_TYPE_INTERFACE_DataSystem", "group__spa__support.html#gadc27e9cd52e02e882a9cff73cc39b84e", null ],
    [ "SPA_TYPE_INTERFACE_DBus", "group__spa__support.html#ga8015339211635f3bcf91ff52a9953678", null ],
    [ "SPA_TYPE_INTERFACE_I18N", "group__spa__support.html#gacc03db6ab5181108527ca45e7674b235", null ],
    [ "SPA_TYPE_INTERFACE_Loop", "group__spa__support.html#ga5ea06c2ace410d56b97b466704b3ded7", null ],
    [ "SPA_TYPE_INTERFACE_LoopControl", "group__spa__support.html#gacafe7661d00fa945b3c4f3471ef3e2c3", null ],
    [ "SPA_TYPE_INTERFACE_LoopUtils", "group__spa__support.html#ga3e3c897298f750f7847db45e0785bb43", null ],
    [ "SPA_TYPE_INTERFACE_PluginLoader", "group__spa__support.html#gade61903a8bd06ae84ad4fa6d6f4035d0", null ],
    [ "SPA_TYPE_INTERFACE_System", "group__spa__support.html#ga54a93b686738ba2115a8cac54202031f", null ],
    [ "SPA_TYPE_INTERFACE_ThreadUtils", "group__spa__support.html#ga6680e7f42845ca460cdaa93abd568e02", null ],
    [ "SPA_VERSION_CPU", "group__spa__support.html#ga6cd931ac7d37bf2a2e4b311cc562cf38", null ],
    [ "SPA_VERSION_DBUS", "group__spa__support.html#ga86263eb7e15c01e44c67b4b92c777a45", null ],
    [ "SPA_VERSION_I18N", "group__spa__support.html#gab6c7211ad9795cf4c1c55487c165a555", null ],
    [ "SPA_VERSION_LOOP", "group__spa__support.html#ga50c88c59a795523063c7f48e517fce74", null ],
    [ "SPA_VERSION_LOOP_CONTROL", "group__spa__support.html#gaf08e046c937b0d412b56b0cccbeeebea", null ],
    [ "SPA_VERSION_LOOP_UTILS", "group__spa__support.html#gae3db9595657af4faae90e6d844291fa7", null ],
    [ "SPA_VERSION_PLUGIN_LOADER", "group__spa__support.html#ga4ad7f76d73f45e3b813415d8eef9652a", null ],
    [ "SPA_VERSION_SYSTEM", "group__spa__support.html#gad8592bcc0072a7f3e01c1c599c31a59a", null ],
    [ "SPA_VERSION_THREAD_UTILS", "group__spa__support.html#ga4f716da417d838544df4e82f4670b79c", null ],
    [ "spa_invoke_func_t", "group__spa__support.html#gab59a4a2bc60d5c26983a0e0edabc6617", null ],
    [ "spa_source_event_func_t", "group__spa__support.html#ga4de35545ca7478aeaf64f46434262346", null ],
    [ "spa_source_func_t", "group__spa__support.html#ga809d037b8643139b58878b4b31b28cf6", null ],
    [ "spa_source_idle_func_t", "group__spa__support.html#ga710acda9d2c12a7d44236e5b1024e941", null ],
    [ "spa_source_io_func_t", "group__spa__support.html#gacb78ee7f8a1948db3767b3f9c82f7370", null ],
    [ "spa_source_signal_func_t", "group__spa__support.html#ga5484a18b8cc8060d6397589465948378", null ],
    [ "spa_source_timer_func_t", "group__spa__support.html#ga12c55826c9d89a9d385da0363ee586d9", null ],
    [ "spa_dbus_type", "group__spa__support.html#ga39128520ce2167eb64279fc23e617fa0", [
      [ "SPA_DBUS_TYPE_SESSION", "group__spa__support.html#gga39128520ce2167eb64279fc23e617fa0a1527a1d0ef093fd2a6cddc424d80b2d2", null ],
      [ "SPA_DBUS_TYPE_SYSTEM", "group__spa__support.html#gga39128520ce2167eb64279fc23e617fa0a5fdca2872c84184d6a5ca0701726d229", null ],
      [ "SPA_DBUS_TYPE_STARTER", "group__spa__support.html#gga39128520ce2167eb64279fc23e617fa0a4645a44a9d5954b882e7a3c23672fed8", null ]
    ] ],
    [ "spa_dbus_get_connection", "group__spa__support.html#ga65dee1ac21fd250bba7fbfe30b94543d", null ],
    [ "spa_i18n_ntext", "group__spa__support.html#ga6308906880809caec1ec322e65909f59", null ],
    [ "spa_i18n_text", "group__spa__support.html#gab1de4a438f825c82bf302b42044dce37", null ],
    [ "spa_plugin_loader_load", "group__spa__support.html#gaf2597e1ad1db500c9a8f7b850e1c1243", null ],
    [ "spa_plugin_loader_unload", "group__spa__support.html#ga8cabaa285c9e5d41260de5f74d8cecf0", null ],
    [ "spa_thread_utils_acquire_rt", "group__spa__support.html#gaf8856d51b5173c7404fe9ba0b468e216", null ],
    [ "spa_thread_utils_create", "group__spa__support.html#ga557081e739fe47934c2c2ac7093af754", null ],
    [ "spa_thread_utils_drop_rt", "group__spa__support.html#ga8d4d667abd5d5128cd9885d6cc862aa7", null ],
    [ "spa_thread_utils_get_rt_range", "group__spa__support.html#ga070bc3ef2e89b7560d9d4382b4359716", null ],
    [ "spa_thread_utils_join", "group__spa__support.html#gaa2f318d1cb2652f24ec0d2c0e1e95556", null ]
];